==> qcad_1.3.3.orig.tar.gz: qcad-1.3.3.orig/rxpmapp.h <==
/***************************************************************************
                          rxpmapp.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

#ifndef RXPMAPP_H
#define RXPMAPP_H

#include <qpixmap.h>

#ifdef DEF_CAM_EXPERT
#include "xpm/camexpert.xpm"
#endif

#ifdef DEF_QCAD
#include "xpm/qcad.xpm"
#endif

#include "xpm/document.xpm"

#include "xpm/filenew.xpm"
#include "xpm/fileopen.xpm"
#include "xpm/fileprint.xpm"
#include "xpm/filesave.xpm"
#include "xpm/fileprintsetup.xpm"
#include "xpm/fileprintprev.xpm"
#include "xpm/fileclose.xpm"

#ifdef DEF_CAM_EXPERT
#include "xpm/filecloseoutput.xpm"
#endif

#include "xpm/filerecall.xpm"

#include "xpm/zoomauto.xpm"
#include "xpm/zoomwindow.xpm"
#include "xpm/zoomredraw.xpm"
#include "xpm/zoompan.xpm"
#include "xpm/zoomincrease.xpm"
#include "xpm/zoomdecrease.xpm"
#include "xpm/zoomtagged.xpm"

#include "xpm/cadmenupoint.xpm"
#include   "xpm/cadpointsingle.xpm"

#include "xpm/cadmenuline.xpm"
#include   "xpm/cadlinesnormal.xpm"
#include   "xpm/cadlineshor.xpm"
#include   "xpm/cadlinesver.xpm"
#include   "xpm/cadlinesangle.xpm"
#include   "xpm/cadlinesrect.xpm"
#include   "xpm/cadlinespara.xpm"
#include   "xpm/cadlinesbisector.xpm"
#include   "xpm/cadlinestan1.xpm"
#include   "xpm/cadlinestan2.xpm"
#include   "xpm/cadlinesortho.xpm"
#include   "xpm/cadlinesortho2.xpm"

#include "xpm/cadmenuarc.xpm"
#include   "xpm/cadarcscraa.xpm"
#include   "xpm/cadarcsppp.xpm"
#include   "xpm/cadarcspara.xpm"

#include "xpm/cadmenucircle.xpm"
#include   "xpm/cadcirclescr.xpm"

#include "xpm/cadmenutext.xpm"

#include "xpm/cadmenudim.xpm"
#include   "xpm/caddimspara.xpm"
#include   "xpm/caddimshor.xpm"
#include   "xpm/caddimsver.xpm"
#include   "xpm/caddimsangle.xpm"
#include   "xpm/caddimsdiam.xpm"
#include   "xpm/caddimsrad.xpm"
#include   "xpm/caddimsarrow.xpm"

#include "xpm/cadmenuhatch.xpm"

#include "xpm/cadmenutag.xpm"
#include   "xpm/tagall.xpm"
#include   "xpm/tagnothing.xpm"
#include   "xpm/tagelement.xpm"
#include   "xpm/tagcontour.xpm"
#include   "xpm/tagrange.xpm"
#include   "xpm/untagrange.xpm"
#include   "xpm/taginters.xpm"
#include   "xpm/untaginters.xpm"
#include   "xpm/taginvert.xpm"
#include   "xpm/taglayer.xpm"
#include   "xpm/tagdoubles.xpm"
#include   "xpm/tagenough.xpm"

#include "xpm/cadmenuedit.xpm"
#include   "xpm/editmove.xpm"
#include   "xpm/editrotate.xpm"
#include   "xpm/editscale.xpm"
#include   "xpm/editmirror.xpm"
#include   "xpm/editmoverot.xpm"
#include   "xpm/editrotrot.xpm"
#include   "xpm/edittrim.xpm"
#include   "xpm/edittrim2.xpm"
#include   "xpm/editcut.xpm"
#include   "xpm/editstretch.xpm"
#include   "xpm/editround.xpm"
#include   "xpm/editbevel.xpm"
#include   "xpm/edittextelement.xpm"
#include   "xpm/edittext.xpm"
#include   "xpm/editdelete.xpm"
#include   "xpm/editlayer.xpm"
#include   "xpm/editzero.xpm"
#include   "xpm/editattrib.xpm"

//#include "xpm/cadmenumeasure.xpm"
//#include "xpm/cadmenuzoom.xpm"

#ifdef DEF_CAM_EXPERT
#include "xpm/cadmenucam.xpm"
#endif

//#include "xpm/cadmenucamtool.xpm"

#include "xpm/snapfree.xpm"
#include "xpm/snapgrid.xpm"
#include "xpm/snapendpoints.xpm"
#include "xpm/snapcenters.xpm"
#include "xpm/snapmiddles.xpm"
#include "xpm/snapautointer.xpm"
#include "xpm/snapmaninter.xpm"
#include "xpm/snapdist.xpm"
#include "xpm/snaponelement.xpm"
#include "xpm/snapkeyxy.xpm"
#include "xpm/snapkeyar.xpm"

//#include "xpm/helpsnapkeyxy.xpm"
//#include "xpm/helpsnapkeyar.xpm"

#include "xpm/modeabs.xpm"
#include "xpm/moderel.xpm"

#ifdef DEF_CAM_EXPERT
#include "xpm/camauto.xpm"
#include "xpm/cammanual.xpm"

#include "xpm/modeconstruction.xpm"
#include "xpm/modecomparison.xpm"
#include "xpm/modesimulation.xpm"

#include "xpm/confmachgen.xpm"
#endif

#include "xpm/helpabout.xpm"
#include "xpm/helpmanual.xpm"

#include "xpm/copy.xpm"
#include "xpm/cut.xpm"
#include "xpm/paste.xpm"

#include "xpm/undo.xpm"
#include "xpm/redo.xpm"
  
#endif

==> qcad_1.5.4.orig.tar.gz: qcad-1.5.4/rxpmapp.h <==
/***************************************************************************
                          rxpmapp.h  -  description
                             -------------------
    begin                : Mon Sep 27 1999
    copyright            : (C) 1999 by Andreas Mustun
    email                : andrew@ribbonsoft.com
 ***************************************************************************/

#ifndef RXPMAPP_H
#define RXPMAPP_H

#include <qpixmap.h>

#include "xpm/qcad.xpm"
#ifdef DEF_SGI
#include "xpm/qcadsgi.xpm"
#endif
#include "xpm/document.xpm"
#include "xpm/filenew.xpm"
#include "xpm/fileopen.xpm"
#include "xpm/fileprint.xpm"
#include "xpm/filesave.xpm"
#include "xpm/fileprintsetup.xpm"
#include "xpm/fileprintprev.xpm"
#include "xpm/fileclose.xpm"

#ifdef DEF_CAM_EXPERT
#include "xpm/filecloseoutput.xpm"
#include "xpm/camexp.xpm"
#endif

#include "xpm/filerecall.xpm"

#include "xpm/zoomauto.xpm"
#include "xpm/zoomtopage.xpm"
#include "xpm/zoomwindow.xpm"
#include "xpm/zoomredraw.xpm"
#include "xpm/zoompan.xpm"
#include "xpm/zoomincrease.xpm"
#include "xpm/zoomdecrease.xpm"
#include "xpm/zoomtagged.xpm"
#include "xpm/zoomone.xpm"

#include "xpm/cadmenupoint.xpm"
#include   "xpm/cadpointsingle.xpm"

#include "xpm/cadmenuline.xpm"
#include   "xpm/cadlinesnormal.xpm"
#include   "xpm/cadlineshor.xpm"
#include   "xpm/cadlinesver.xpm"
#include   "xpm/cadlinesangle.xpm"
#include   "xpm/cadlinesrect.xpm"
#include   "xpm/cadlinespara.xpm"
#include   "xpm/cadlinesbisector.xpm"
#include   "xpm/cadlinestan1.xpm"
#include   "xpm/cadlinestan2.xpm"
#include   "xpm/cadlinesortho.xpm"
#include   "xpm/cadlinesortho2.xpm"

#include "xpm/cadmenuarc.xpm"
#include   "xpm/cadarcscraa.xpm"
#include   "xpm/cadarcsppp.xpm"
#include   "xpm/cadarcspara.xpm"

#include "xpm/cadmenucircle.xpm"
#include   "xpm/cadcirclescr.xpm"
#include   "xpm/cadcirclescl.xpm"
#include   "xpm/cadcircles3p.xpm"

#include "xpm/cadmenutext.xpm"

#include "xpm/cadmenudim.xpm"
#include   "xpm/caddimspara.xpm"
#include   "xpm/caddimshor.xpm"
#include   "xpm/caddimsver.xpm"
#include   "xpm/caddimsangle.xpm"
#include   "xpm/caddimsdiam.xpm"
#include   "xpm/caddimsrad.xpm"
#include   "xpm/caddimsarrow.xpm"

#include "xpm/cadmenuhatch.xpm"

#include "xpm/cadmenutag.xpm"
#include   "xpm/tagall.xpm"
#include   "xpm/tagnothing.xpm"
#include   "xpm/tagelement.xpm"
#include   "xpm/tagcontour.xpm"
#include   "xpm/tagrange.xpm"
#include   "xpm/untagrange.xpm"
#include   "xpm/taginters.xpm"
#include   "xpm/untaginters.xpm"
#include   "xpm/taginvert.xpm"
#include   "xpm/taglayer.xpm"
#include   "xpm/tagdoubles.xpm"
#include   "xpm/tagenough.xpm"

#include "xpm/cadmenuedit.xpm"
#include   "xpm/editmove.xpm"
#include   "xpm/editrotate.xpm"
#include   "xpm/editscale.xpm"
#include   "xpm/editmirror.xpm"
#include   "xpm/editmoverot.xpm"
#include   "xpm/editrotrot.xpm"
#include   "xpm/edittrim.xpm"
#include   "xpm/edittrim2.xpm"
#include   "xpm/edittrim3.xpm"
#include   "xpm/editcut.xpm"
#include "xpm/editcut2.xpm"
#include   "xpm/editstretch.xpm"
#include   "xpm/editround.xpm"
#include   "xpm/editbevel.xpm"
#include   "xpm/edittextelement.xpm"
#include   "xpm/edittext.xpm"
#include   "xpm/editdelete.xpm"
#include   "xpm/editlayer.xpm"
#include   "xpm/editzero.xpm"
#include   "xpm/editattrib.xpm"
#include   "xpm/editclip.xpm"

#include "xpm/cadmenumeasure.xpm"
#include   "xpm/measureptpt.xpm"
#include   "xpm/measurelnpt.xpm"
#include   "xpm/measureparallellines.xpm"
#include   "xpm/measureanglelnln.xpm"
#include   "xpm/measureeditelement.xpm"
#include   "xpm/measurearea.xpm"

//#include "xpm/cadmenumeasure.xpm"
//#include "xpm/cadmenuzoom.xpm"

#ifdef DEF_CAM_EXPERT
#include "xpm/cadmenucam.xpm"
#endif

//#include "xpm/cadmenucamtool.xpm"

#include "xpm/snapfree.xpm"
#include "xpm/snapgrid.xpm"
#include "xpm/snapendpoints.xpm"
#include "xpm/snapcenters.xpm"
#include "xpm/snapmiddles.xpm"
#include "xpm/snapautointer.xpm"
#include "xpm/snapmaninter.xpm"
#include "xpm/snapdist.xpm"
#include "xpm/snaponelement.xpm"
#include "xpm/snapkeyxy.xpm"
#include "xpm/snapkeyar.xpm"

//#include "xpm/helpsnapkeyxy.xpm"
//#include "xpm/helpsnapkeyar.xpm"

#include "xpm/modeabs.xpm"
#include "xpm/moderel.xpm"

#ifdef DEF_CAM_EXPERT
#include "xpm/camauto.xpm"
//#include "xpm/cammanual.xpm"

#include "xpm/modeconstruction.xpm"
#include "xpm/modecomparison.xpm"
#include "xpm/modesimulation.xpm"

#include "xpm/confmachgen.xpm"
#endif

#include "xpm/helpabout.xpm"
#include "xpm/helpmanual.xpm"

#include "xpm/librarybrowser.xpm"

#include "xpm/copy.xpm"
#include "xpm/cut.xpm"
#include "xpm/paste.xpm"

#include "xpm/undo.xpm"
#include "xpm/redo.xpm"
  
#endif
